==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Downloads/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","˹ҡ͹");
define("_NEXT","˹ҶѴ");
define("_CATEGORY","");
define("_CATEGORIES","");
define("_LVOTES","ʴ");
define("_TOTALVOTES","繷:");
define("_THEREARE","йպԨó");
define("_NOMATCHES","辺ŵç͹");
define("_SCOMMENTS","");
define("_UNKNOWN","Unknown");
define("_DOWNLOADS","Ŵ");
define("_FILESIZE","File Size");
define("_VERSION","Version");
define("_DESCRIPTION","Description");
define("_AUTHOR","Author");
define("_HOMEPAGE","HomePage");
define("_DOWNLOADNOW","Download this file Now!");
define("_DATE","ѹ");
define("_TO","֧");
define("_NEW","Link ");
define("_POPULAR","Link ʹ");
define("_TOPRATED","ش ");
define("_ADDITIONALDET","´");
define("_EDITORREVIEW","óҸԡþԨó");
define("_REPORTBROKEN","§ҹ Broken Link");
define("_AND","");
define("_INDB","㹰ҹŹ");
define("_INSTRUCTIONS","й");
define("_USERANDIP","¡  ͧ IP ж١ѹ֡ͻͧѹáзӷԴ");
define("_LDESCRIPTION","´: (Թ 255 ѡ)");
define("_CHECKFORIT","ҹк  ҧá  ҨзӡõǨͺ link ʹ ѧ");
define("_LASTWEEK","ѻ");
define("_LAST30DAYS","ǧ 30 ѹ");
define("_1WEEK","1 ѻ");
define("_2WEEKS","2 ѻ");
define("_30DAYS","30 ѹ");
define("_SHOW","ʴ");
define("_DAYS","ѹ");
define("_ADDEDON","Added on");
define("_RATING","ṹ");
define("_DETAILS","´");
define("_OF","ͧ");
define("_TVOTESREQ","ṹҧ ");
define("_SHOWTOP","ʴʹ ");
define("_MOSTPOPULAR","Ѻش  - Top");
define("_OFALL","ͧ");
define("_POPULARITY","");
define("_SELECTPAGE","͡˹");
define("_MAIN","˹á");
define("_NEWTODAY","Ѻѹ ");
define("_NEWLAST3DAYS","ǧ 3 ѹ");
define("_NEWTHISWEEK","ѻ");
define("_POPULARITY1","Popularity (Least to Most Hits)");
define("_POPULARITY2","Popularity (Most to Least Hits)");
define("_TITLEAZ","Title (A to Z)");
define("_TITLEZA","Title (Z to A)");
define("_RATING1","Rating (Lowest Scores to Highest Scores)");
define("_RATING2","Rating (Highest Scores to Lowest Scores)");
define("_SEARCHRESULTS4","Search Results for");
define("_USUBCATEGORIES","Sub-Categories");
define("_TRY2SEARCH","Try to search");
define("_INOTHERSENGINES","in others Search Engines");
define("_EDITORIAL","Editorial");
define("_EDITORIALBY","Editorial by");
define("_NOEDITORIAL","No editorial is currently available for this website.");
define("_RATETHISSITE","Rate this Website");
define("_ISTHISYOURSITE","Is this your resource?");
define("_ALLOWTORATE","Allow other users to rate it from your web site!");
define("_OVERALLRATING","Overall Rating");
define("_TOTALOF","Total of");
define("_USER","User");
define("_USERAVGRATING","User's Average Rating");
define("_NUMRATINGS","# of Ratings");
define("_REGISTEREDUSERS","Registered Users");
define("_NUMBEROFRATINGS","Number of Ratings");
define("_NOREGUSERSVOTES","No Registered User Votes");
define("_BREAKDOWNBYVAL","Breakdown of Ratings by Value");
define("_LTOTALVOTES","total votes");
define("_HIGHRATING","High Rating");
define("_LOWRATING","Low Rating");
define("_NUMOFCOMMENTS","Number of Comments");
define("_WEIGHNOTE","* Note: This website weighs Registered vs. Unregistered users ratings");
define("_NOUNREGUSERSVOTES","No Unregistered User Votes");
define("_WEIGHOUTNOTE","* Note: This website weighs Registered vs. Outside voters ratings");
define("_NOOUTSIDEVOTES","No Outside Votes");
define("_OUTSIDEVOTERS","Outside Voters");
define("_UNREGISTEREDUSERS","Unregistered Users");
define("_PROMOTEYOURSITE","Promote Your Website");
define("_PROMOTE01","Maybe you can be interested in several of the remote 'Rate a Website' options we have available. These allow you to place an image (or even a rating form) on your web site in order to increase the number of votes your website receive. Please choose from one of the options listed below:");
define("_TEXTLINK","Text Link");
define("_PROMOTE02","One way to link to the rating form is through a simple text link:");
define("_HTMLCODE1","The HTML code you should use in this case, is the following:");
define("_THENUMBER","The Number");
define("_IDREFER","in the HTML source references your site's ID number in $sitename database. Be sure this number is present.");
define("_BUTTONLINK","Button Link");
define("_PROMOTE03","If you're looking for a little more than a basic text link, you may wish to use a small button link:");
define("_RATEIT","Rate this Site!");
define("_HTMLCODE2","The source code for the above button is:");
define("_REMOTEFORM","Remote Rating Form");
define("_PROMOTE04","If you cheat on this, we'll remove your link. Having said that, here is what the current remote rating form looks like.");
define("_VOTE4THISSITE","Vote for this Site!");
define("_HTMLCODE3","Using this form will allow users to rate your website directly from your site and the rating will be recorded here. The above form is disabled, but the following source code will work if you simply cut and paste it into your web page. The source code is shown below:");
define("_PROMOTE05","Thanks! and good luck with your ratings!");
define("_STAFF","Staff");
define("_THANKSBROKEN","Thank you for helping to maintain this directory's integrity.");
define("_SECURITYBROKEN","For security reasons your user name and IP address will also be temporarily recorded.");
define("_THANKSFORINFO","Thanks for the information.");
define("_LOOKTOREQUEST","We'll look into your request shortly.");
define("_SENDREQUEST","Send Request");
define("_THANKSTOTAKETIME","Thank you for taking the time to rate a site here at");
define("_RETURNTO","Return to");
define("_RATENOTE1","Please do not vote for the same resource more than once.");
define("_RATENOTE2","The scale is 1 - 10, with 1 being poor and 10 being excellent.");
define("_RATENOTE3","Please be objective in your vote, if everyone receives a 1 or a 10, the ratings aren't very useful.");
define("_RATENOTE5","Do not vote for your own resource or a competitor's.");
define("_YOUAREREGGED","You are a registered user and are logged in.");
define("_FEELFREE2ADD","Feel free to add a comment about this site.");
define("_YOUARENOTREGGED","You are not a registered user or you have not logged in.");
define("_IFYOUWEREREG","If you were registered you could make comments on this website.");
define("_TITLE","Title");
define("_MODIFY","Modify");
define("_ADDDOWNLOAD","Add Download");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b -%Y");
define("_AUTHORNAME","Author's Name");
define("_AUTHOREMAIL","Author's Email");
define("_DOWNLOADNAME","Program Name");
define("_ADDTHISFILE","Add this file");
define("_INBYTES","in bytes");
define("_RATERESOURCE","Rate Resource");
define("_DSUBMITONCE","Submit a unique download only once.");
define("_DPOSTPENDING","All downloads are posted pending verification.");
define("_DTOTALFORLAST","Total new downloads for last");
define("_DBESTRATED","Best Rated Downloads - Top");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Downloads/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","˹ҡ͹");
define("_NEXT","˹ҶѴ");
define("_CATEGORY","");
define("_CATEGORIES","");
define("_LVOTES","ʴ");
define("_TOTALVOTES","繷:");
define("_THEREARE","йպԨó");
define("_NOMATCHES","辺ŵç͹");
define("_SCOMMENTS","");
define("_UNKNOWN","Unknown");
define("_DOWNLOADS","Ŵ");
define("_FILESIZE","File Size");
define("_VERSION","Version");
define("_DESCRIPTION","Description");
define("_AUTHOR","Author");
define("_HOMEPAGE","HomePage");
define("_DOWNLOADNOW","Download this file Now!");
define("_DATE","ѹ");
define("_TO","֧");
define("_NEW","Link ");
define("_POPULAR","Link ʹ");
define("_TOPRATED","ش ");
define("_ADDITIONALDET","´");
define("_EDITORREVIEW","óҸԡþԨó");
define("_REPORTBROKEN","§ҹ Broken Link");
define("_AND","");
define("_INDB","㹰ҹŹ");
define("_INSTRUCTIONS","й");
define("_USERANDIP","¡  ͧ IP ж١ѹ֡ͻͧѹáзӷԴ");
define("_LDESCRIPTION","´: (Թ 255 ѡ)");
define("_CHECKFORIT","ҹк  ҧá  ҨзӡõǨͺ link ʹ ѧ");
define("_LASTWEEK","ѻ");
define("_LAST30DAYS","ǧ 30 ѹ");
define("_1WEEK","1 ѻ");
define("_2WEEKS","2 ѻ");
define("_30DAYS","30 ѹ");
define("_SHOW","ʴ");
define("_DAYS","ѹ");
define("_ADDEDON","Added on");
define("_RATING","ṹ");
define("_DETAILS","´");
define("_OF","ͧ");
define("_TVOTESREQ","ṹҧ ");
define("_SHOWTOP","ʴʹ ");
define("_MOSTPOPULAR","Ѻش  - Top");
define("_OFALL","ͧ");
define("_POPULARITY","");
define("_SELECTPAGE","͡˹");
define("_MAIN","˹á");
define("_NEWTODAY","Ѻѹ ");
define("_NEWLAST3DAYS","ǧ 3 ѹ");
define("_NEWTHISWEEK","ѻ");
define("_POPULARITY1","Popularity (Least to Most Hits)");
define("_POPULARITY2","Popularity (Most to Least Hits)");
define("_TITLEAZ","Title (A to Z)");
define("_TITLEZA","Title (Z to A)");
define("_RATING1","Rating (Lowest Scores to Highest Scores)");
define("_RATING2","Rating (Highest Scores to Lowest Scores)");
define("_SEARCHRESULTS4","Search Results for");
define("_USUBCATEGORIES","Sub-Categories");
define("_TRY2SEARCH","Try to search");
define("_INOTHERSENGINES","in others Search Engines");
define("_EDITORIAL","Editorial");
define("_EDITORIALBY","Editorial by");
define("_NOEDITORIAL","No editorial is currently available for this website.");
define("_RATETHISSITE","Rate this Website");
define("_ISTHISYOURSITE","Is this your resource?");
define("_ALLOWTORATE","Allow other users to rate it from your web site!");
define("_OVERALLRATING","Overall Rating");
define("_TOTALOF","Total of");
define("_USER","User");
define("_USERAVGRATING","User's Average Rating");
define("_NUMRATINGS","# of Ratings");
define("_REGISTEREDUSERS","Registered Users");
define("_NUMBEROFRATINGS","Number of Ratings");
define("_NOREGUSERSVOTES","No Registered User Votes");
define("_BREAKDOWNBYVAL","Breakdown of Ratings by Value");
define("_LTOTALVOTES","total votes");
define("_HIGHRATING","High Rating");
define("_LOWRATING","Low Rating");
define("_NUMOFCOMMENTS","Number of Comments");
define("_WEIGHNOTE","* Note: This website weighs Registered vs. Unregistered users ratings");
define("_NOUNREGUSERSVOTES","No Unregistered User Votes");
define("_WEIGHOUTNOTE","* Note: This website weighs Registered vs. Outside voters ratings");
define("_NOOUTSIDEVOTES","No Outside Votes");
define("_OUTSIDEVOTERS","Outside Voters");
define("_UNREGISTEREDUSERS","Unregistered Users");
define("_PROMOTEYOURSITE","Promote Your Website");
define("_PROMOTE01","Maybe you can be interested in several of the remote 'Rate a Website' options we have available. These allow you to place an image (or even a rating form) on your web site in order to increase the number of votes your website receive. Please choose from one of the options listed below:");
define("_TEXTLINK","Text Link");
define("_PROMOTE02","One way to link to the rating form is through a simple text link:");
define("_HTMLCODE1","The HTML code you should use in this case, is the following:");
define("_THENUMBER","The Number");
define("_IDREFER","in the HTML source references your site's ID number in $sitename database. Be sure this number is present.");
define("_BUTTONLINK","Button Link");
define("_PROMOTE03","If you're looking for a little more than a basic text link, you may wish to use a small button link:");
define("_RATEIT","Rate this Site!");
define("_HTMLCODE2","The source code for the above button is:");
define("_REMOTEFORM","Remote Rating Form");
define("_PROMOTE04","If you cheat on this, we'll remove your link. Having said that, here is what the current remote rating form looks like.");
define("_VOTE4THISSITE","Vote for this Site!");
define("_HTMLCODE3","Using this form will allow users to rate your website directly from your site and the rating will be recorded here. The above form is disabled, but the following source code will work if you simply cut and paste it into your web page. The source code is shown below:");
define("_PROMOTE05","Thanks! and good luck with your ratings!");
define("_STAFF","Staff");
define("_THANKSBROKEN","Thank you for helping to maintain this directory's integrity.");
define("_SECURITYBROKEN","For security reasons your user name and IP address will also be temporarily recorded.");
define("_THANKSFORINFO","Thanks for the information.");
define("_LOOKTOREQUEST","We'll look into your request shortly.");
define("_SENDREQUEST","Send Request");
define("_THANKSTOTAKETIME","Thank you for taking the time to rate a site here at");
define("_RETURNTO","Return to");
define("_RATENOTE1","Please do not vote for the same resource more than once.");
define("_RATENOTE2","The scale is 1 - 10, with 1 being poor and 10 being excellent.");
define("_RATENOTE3","Please be objective in your vote, if everyone receives a 1 or a 10, the ratings aren't very useful.");
define("_RATENOTE5","Do not vote for your own resource or a competitor's.");
define("_YOUAREREGGED","You are a registered user and are logged in.");
define("_FEELFREE2ADD","Feel free to add a comment about this site.");
define("_YOUARENOTREGGED","You are not a registered user or you have not logged in.");
define("_IFYOUWEREREG","If you were registered you could make comments on this website.");
define("_TITLE","Title");
define("_MODIFY","Modify");
define("_ADDDOWNLOAD","Add Download");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b -%Y");
define("_AUTHORNAME","Author's Name");
define("_AUTHOREMAIL","Author's Email");
define("_DOWNLOADNAME","Program Name");
define("_ADDTHISFILE","Add this file");
define("_INBYTES","in bytes");
define("_RATERESOURCE","Rate Resource");
define("_DSUBMITONCE","Submit a unique download only once.");
define("_DPOSTPENDING","All downloads are posted pending verification.");
define("_DTOTALFORLAST","Total new downloads for last");
define("_DBESTRATED","Best Rated Downloads - Top");

?>
